@@ -7,7 +7,17 @@ define([
 ], function($, events){
     "use strict";
 
-    var Page = function () {
+    var Page = function (header_div_selector, site_div_selector) {
+        /**
+        * Constructor
+        *
+        * Parameters
+        * header_div_selector: string
+        * site_div_selector: string
+        */
+        this.header_div_element = $(header_div_selector || 'div#header');
+        this.site_div_element = $(site_div_selector || 'div#site');
+
         this.bind_events();
     };
 
@@ -38,18 +48,16 @@ define([
         /**
          * The header and site divs start out hidden to prevent FLOUC.
          * Main scripts should call this method after styling everything.
-         * TODO: selector are hardcoded, pass as constructor argument
          */
-        $('div#header').css('display','block');
+        this.header_div_element.css('display','block');
     };
 
     Page.prototype.show_site = function () {
         /**
          * The header and site divs start out hidden to prevent FLOUC.
          * Main scripts should call this method after styling everything.
-         * TODO: selector are hardcoded, pass as constructor argument
          */
-        $('div#site').css('display', 'block');
+        this.site_div_element.css('display', 'block');
         this._resize_site();
     };
 
@@ -66,7 +74,21 @@ define([
         if (!(e && e.target && e.target.tagName)) {
             $('div#site').height($(window).height() - $('#header').height());
         }
+        this._align_header_site();
     };
 
+
+
+    Page.prototype._align_header_site = function(e) {
+        /**
+         * Align the site and header divs
+         */
+        var header_div_element_width = this.header_div_element.outerWidth();
+        var header_container_width = $('div#header-container').outerWidth();
+        var margin_left = (header_div_element_width - header_container_width) / 2;
+
+        this.site_div_element.find('.container').css('margin-left', margin_left);
+    }
+
     return {'Page': Page};
 });
